﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace WdtClient.api.sales
{
    public class RawTrade
    {
        // 订单状态
        /**
         * 平台状态 未确认
         */
        public const byte TRADE_STATUS_TO_CONFIRM = 10;
        /**
         * 平台状态 待尾款 
         */
        public const byte TRADE_STATUS_PART_PAID = 20;
        /**
         * 平台状态 待发货 
         */
        public const byte TRADE_STATUS_WAIT_CONSIGN = 30;
        /**
         * 平台状态 部分发货
         */
        public const byte TRADE_STATUS_PART_CONSIGN = 40;
        /**
         * 平台状态  已发货
         */
        public const byte TRADE_STATUS_CONSIGNED = 50;
        /**
         * 平台状态  已签收
         */
        public const byte TRADE_STATUS_SIGNED = 60;
        /**
         * 平台状态  已完成
         */
        public const byte TRADE_STATUS_COMPLETE = 70;
        /**
         * 平台状态  已退款
         */
        public const byte TRADE_STATUS_REFUND = 80;
        /**
         * 平台状态  已关闭(付款前取消)
         */
        public const byte TRADE_STATUS_CLOSED = 90;
        
        //付款状态
        public const byte PAY_STATUS_UNPAY = 0; //未付款
        public const byte PAY_STATUS_PART_PAID = 1; //部分付款
        public const byte PAY_STATUS_FULL_PAID = 2; //已付款

        //退款状态 
        public const byte REFUND_NONE = 0; //无退款
        public const byte REFUND_APPLY = 1; //申请退款
        public const byte REFUND_PART = 2; //部分退款
        public const byte REFUND_FULL = 3; //全部退款  

        /**
         ** 款到发货
         */
        public const byte DELIVERY_TERM_DAP = 1; //款到发货

        /**
         * 货到付款
         */
        public const byte DELIVERY_TERM_COD = 2; //货到付款(包含部分货到付款) 

        public const byte PROCESS_STATUS_WAIT_DELIVERY = 10; //待递交
        public const byte PROCESS_STATUS_CANCEL = 70; //已取消

        public string Tid;
        public byte TradeStatus = TRADE_STATUS_WAIT_CONSIGN;
        public byte PayStatus = PAY_STATUS_FULL_PAID;
        public byte RefundStatus = REFUND_NONE;
        public byte DeliveryTerm = DELIVERY_TERM_DAP;
        public byte ProcessStatus = PROCESS_STATUS_WAIT_DELIVERY;

        public string TradeTime;
        public string PayTime;
        public string BuyerNick;
        public string BuyerEmail = string.Empty;
        public string BuyerArea = string.Empty;
        public string PayId = string.Empty;
        public string PayAccount = string.Empty;
        public string ReceiverName;
        public short ReceiverCountry;   // 国家
        public string ReceiverArea;     // "省份 城市 区县", 以“空格”分隔
        public string ReceiverAddress;
        public string ReceiverMobile;
        public string ReceiverTelno = string.Empty;
		public string ReceiverZip = string.Empty;
        public string ToDeliverTime = string.Empty;
        public byte LogisticsType;                      // 物流类别
        public byte InvoiceType;                        // 1需要开发票
        public string InvoiceTitle = string.Empty;      // 发票抬头
        public string InvoiceContent = string.Empty;    // 发票内容
        public string BuyerMessage = string.Empty;      // 买家留言
		public string Remark = string.Empty;            // 客户备注
        public byte RemarkFlag;         // 标旗 0 无 
        public decimal Receivable;      // 应收金额
        public decimal PostAmount;      // 邮费
		public decimal Discount;        // 折扣
        public decimal Received;        // 已收金额
        public decimal CodAmount;       // COD金额
        public string EndTime;          // 订单结束时间
    }

    public class RawTradeOrder
    {
        public const byte ORDER_TYPE_NORMAL = 0;  // 普通货品
        public const byte ORDER_TYPE_VIRTUAL = 1; // 虚拟货品
        public const byte ORDER_TYPE_SERVICE = 2; // 服务

        //退款状态
        public const byte REFUND_STATUS_NONE = 0; //无退款
        public const byte REFUND_STATUS_CANCEL = 1; //取消退款,
        public const byte REFUND_STATUS_APPLY = 2; //已申请退款,
        public const byte REFUND_STATUS_AGREE = 3; //等待退货,
        public const byte REFUND_STATUS_WAIT_RECEIVE = 4; //等待收货,
        public const byte REFUND_STATUS_SUCCESS = 5; //退款成功
        public const byte REFUND_STATUS_DISCARD = 6; //未付款关闭

        public string Tid;
        public string Oid;
        public byte Status;
        public byte RefundStatus = REFUND_STATUS_NONE;
        public byte OrderType = ORDER_TYPE_NORMAL;

        public string GoodsId;
        public string SpecId;
        public string GoodsNo;
        public string SpecNo;
        public string GoodsName;
        public string SpecName = string.Empty;
        public string Cid = string.Empty;   // 类目ID
        public int Num;                 // 数量
        public decimal Price;           // 优惠前单价
        public decimal AdjustAmount;    // 手工调整金额
        public decimal Discount;        // 非分摊优惠
        public decimal ShareDiscount;   // 分摊优惠
        public decimal TotalAmount;     // 优惠后总金额(未扣ShareDiscount)
        public string Remark = string.Empty;
    }

    public class PushResult
    {
        public int NewCount; // 新增订单数
        public int ChgCount; // 更新订单数;
    }

    public interface RawTradeAPI
    {
        /// <summary>
        /// 推送订单接口
        /// </summary>
        /// <param name="client">IClient</param>
        /// <param name="shopId">店铺Id</param>
        /// <param name="rawTradeList">原始单列表</param>
        /// <param name="rawTradeOrderList">原始子单列表</param>
        /// <returns></returns>
        [Api("sales.RawTrade.pushSelf")]
        PushResult Push(short shopId, List<RawTrade> rawTradeList, List<RawTradeOrder> rawTradeOrderList);
    }
}
