﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace WdtClient.api.sales
{
    /// <summary>
    /// 需要同步的平台货品记录
    /// </summary>
    public class WaitSyncResult
    {
        /// <summary>
        /// 待同步的记录ID列表
        /// </summary>
        public List<int> IdList;

        /// <summary>
        /// 下一次调用的Position
        /// </summary>
        public int Position;
    };


    /// <summary>
    /// 同步记录
    /// </summary>
    public class WaitSyncRecord
    {
        /// <summary>
        /// 平台货品状态 0删除 1在架 2下架
        /// </summary>
        public byte Status;

        /// <summary>
        /// 店铺ID
        /// </summary>
        public short ShopId;
        /// <summary>
        /// 平台货品ID
        /// </summary>
        public string GoodsId;
        /// <summary>
        /// 平台规格ID
        /// </summary>
        public string SpecId;
        /// <summary>
        /// 商家编码
        /// </summary>
        public string SpecOuterId;

        public int Mask;
        public byte MatchTargetType;
        public int MatchTargetId;
        public int StockSynRuleId;
        public string StockSynRuleNo;
        public string StockSynWarehouses;
        public int StockSynMask;
        public int StockSynPercent;

        /// <summary>
        /// 自动上架
        /// </summary>
        public bool IsAutoListing;

        /// <summary>
        /// 自动下架
        /// </summary>
        public bool IsAutoDelisting;

        /// <summary>
        /// 最小同步库存, 
        ///     如果IsAutoListing=true,SynStock >= StockSynMin则需要自动上架
        ///     如果IsAutoDelisting=true,且SynStock < StockSynMin则需要下去下架
        /// </summary>
        public int StockSynMin;

        /// <summary>
        /// 最大同步库存
        /// </summary>
        public int StockSynMax;

        /// <summary>
        /// 最后同步库存量
        /// </summary>
        public int LastSyncNum;

        /// <summary>
        /// 最后同步时间
        /// </summary>
        public string LastSynTime;

        /// <summary>
        /// 本次需要同步库存量
        /// </summary>
        public int SynStock;

        /// <summary>
        /// 库存变更记录
        /// </summary>
        public int StockChangeCount;

    };
    
    public interface StockSyncAPI
    {
        /// <summary>
        /// 查询需要同步的平台货品记录
        /// int position = 0;
        /// do
        /// {
        ///     WaitSyncResult result = getWaitSyncIdList(client, 500, position);
        ///     if(result.IdList.Count == 0)
        ///         break;
        ///      
        ///     position = result.Position;
        /// } while(true);
        /// </summary>
        /// <param name="client">Client对象</param>
        /// <param name="count">一次返回记录的条数(最小值10, 最大值5000)</param>
        /// <param name="position">起始位置, 第一次用0, 以后则使用上一次调用返回的position</param>
        /// <returns></returns>
        [Api("sales.StockSync.getSelfWaitSyncIdList")]
        WaitSyncResult GetWaitSyncIdList(int count, int position);

        /// <summary>
        /// 计算平台货品库存
        /// </summary>
        /// <param name="client"></param>
        /// <param name="id">平台货品ID</param>
        /// <param name="forceSync">是否强制同步</param>
        /// <returns></returns>
        [Api("sales.StockSync.calcStock")]
        WaitSyncRecord CalcStock(int id, bool forceSync);

        /// <summary>
        /// 取消记录同步, 该记录如果库存发生变更, 会再次同步
        /// </summary>
        /// <param name="client"></param>
        /// <param name="id">平台货品ID</param>
        /// <param name="stockChangeCount"></param>
        [Api("sales.StockSync.cancelSync")]
        void CancelSync(long id, int stockChangeCount);

        /// <summary>
        /// 修改平台货品状态
        /// </summary>
        /// <param name="client"></param>
        /// <param name="id">平台货品ID</param>
        /// <param name="status">0删除 1在架 2下架</param>
        [Api("sales.StockSync.changeStatus")]
        void ChageStatus(long id, int status);

        /// <summary>
        /// 禁止同步, 除非再次打开，否则不会再次同步
        /// </summary>
        /// <param name="client"></param>
        /// <param name="id"></param>
        /// <param name="reason"></param>
        [Api("sales.StockSync.disableSync")]
        void DisableSync(long id, string reason);

        /// <summary>
        /// 标记为同步成功
        /// </summary>
        /// <param name="client"></param>
        /// <param name="id"></param>
        /// <param name="record"></param>
        [Api("sales.StockSync.syncSuccess")]
        void SyncSuccess(long id, WaitSyncRecord record);

        /// <summary>
        /// 标记为同步失败
        /// </summary>
        /// <param name="client"></param>
        /// <param name="id"></param>
        /// <param name="record"></param>
        [Api("sales.StockSync.syncFail")]
        void SyncFail(long id, WaitSyncRecord record);


    }
}
